mafw.examples.sum\_processor
============================

.. automodule:: mafw.examples.sum_processor

   
   .. rubric:: Classes

   .. autosummary::
   
      AccumulatorProcessor
      GaussAdder
   